#include <Keyboard.h>
#include <Bounce2.h>
#include "FastLED.h"

// Bounce object automatically debounces switches
// 2nd Parameter is debound time.  Default 10 ms
Bounce button0 = Bounce(4, 10);
Bounce button1 = Bounce(5, 10);
Bounce button2 = Bounce(6, 10);
Bounce button3 = Bounce(7, 10);
Bounce button4 = Bounce(8, 10);
Bounce button5 = Bounce(2, 10);
Bounce button6 = Bounce(3, 10);

#define DATA_PIN_A 14  // 15 WS2812B LEDs
#define DATA_PIN_B 15  //  7 SK6812-MINI-E LEDs (switch backlights)

#define LED_TYPE_A WS2812B
#define COLOR_ORDER_A GRB
#define BRIGHTNESS 64
#define LED_TYPE_B WS2812B //SK6812-MINI-E LEDs control like WS2812B LEDs
#define COLOR_ORDER_B GRB
#define BRIGHTNESS 128

#define NUM_LEDS_A 15  
#define NUM_LEDS_B 7

CRGB ledsA[NUM_LEDS_A];
CRGB ledsB[NUM_LEDS_B];

void setup() {
  pinMode(4, INPUT_PULLUP);
  pinMode(5, INPUT_PULLUP);
  pinMode(6, INPUT_PULLUP);
  pinMode(7, INPUT_PULLUP);
  pinMode(8, INPUT_PULLUP);
  pinMode(3, INPUT_PULLUP);
  pinMode(2, INPUT_PULLUP);
  FastLED.addLeds<LED_TYPE_A, DATA_PIN_A, COLOR_ORDER_A>(ledsA, NUM_LEDS_A);
  FastLED.addLeds<LED_TYPE_B, DATA_PIN_B, COLOR_ORDER_B>(ledsB, NUM_LEDS_B);
  FastLED.setBrightness(BRIGHTNESS);
  FastLED.clear();
  LED_B_setup();
  LED_A_lightshow();
}

void LED_A_lightshow() {
  for (int hue=0; hue<400; hue+=5) {
     fill_rainbow(ledsA, NUM_LEDS_A, hue, 7);
     FastLED.show();
     delay(50);
  }
}

void LED_B_setup() {
  ledsB[0] = CRGB::Blue;
  ledsB[1] = CRGB::Blue;
  ledsB[2] = 0xFF4400;  //this value looks more like orange
  ledsB[3] = CRGB::Blue;
  ledsB[4] = 0xFFAA00;  //this value looks more like yellow 
  ledsB[5] = CRGB::Red;
  ledsB[6] = CRGB::Green;
  FastLED.show();
}

void loop() {
  button0.update();
  button1.update();
  button2.update();
  button3.update();
  button4.update();
  button5.update();
  button6.update();

  if (button0.fallingEdge()) 
    Keyboard.press('a');
  if (button0.risingEdge()) 
    Keyboard.release('a');
  if (button1.fallingEdge()) 
    Keyboard.press('s');
  if (button1.risingEdge())
    Keyboard.release('s');
  if (button2.fallingEdge()) 
    Keyboard.press('j');
  if (button2.risingEdge()) 
    Keyboard.release('j');    
  if (button3.fallingEdge()) 
    Keyboard.press('k');
  if (button3.risingEdge()) 
    Keyboard.release('k');
  if (button4.fallingEdge()) 
    Keyboard.press('l');
  if (button4.risingEdge()) 
    Keyboard.release('l'); 
  if (button5.fallingEdge()) 
    Keyboard.press(KEY_UP_ARROW);
  if (button5.risingEdge()) 
    Keyboard.release(KEY_UP_ARROW);  
  if (button6.fallingEdge()) 
    Keyboard.press(KEY_DOWN_ARROW);
  if (button6.risingEdge()) 
    Keyboard.release(KEY_DOWN_ARROW);
}
